@@ -13,23 +13,16 @@
 //    Age: 223
 //    Location: Middle-earth
 // ```
-use teloxide::{dispatching2::dialogue::InMemStorage, macros::DialogueState, prelude2::*};
+use teloxide::{dispatching::dialogue::InMemStorage, prelude::*};
 
 type MyDialogue = Dialogue<State, InMemStorage<State>>;
+type HandlerResult = Result<(), Box<dyn std::error::Error + Send + Sync>>;
 
-#[derive(DialogueState, Clone)]
-#[handler_out(anyhow::Result<()>)]
+#[derive(Clone)]
 pub enum State {
-    #[handler(handle_start)]
     Start,
-
-    #[handler(handle_receive_full_name)]
     ReceiveFullName,
-
-    #[handler(handle_receive_age)]
     ReceiveAge { full_name: String },
-
-    #[handler(handle_receive_location)]
     ReceiveLocation { full_name: String, age: u8 },
 }
 
@@ -50,7 +43,13 @@ async fn main() {
         bot,
         Update::filter_message()
             .enter_dialogue::<Message, InMemStorage<State>, State>()
-            .dispatch_by::<State>(),
+            .branch(teloxide::handler![State::Start].endpoint(start))
+            .branch(teloxide::handler![State::ReceiveFullName].endpoint(receive_full_name))
+            .branch(teloxide::handler![State::ReceiveAge { full_name }].endpoint(receive_age))
+            .branch(
+                teloxide::handler![State::ReceiveLocation { full_name, age }]
+                    .endpoint(receive_location),
+            ),
     )
     .dependencies(dptree::deps![InMemStorage::<State>::new()])
     .build()
@@ -59,21 +58,17 @@ async fn main() {
     .await;
 }
 
-async fn handle_start(
-    bot: AutoSend<Bot>,
-    msg: Message,
-    dialogue: MyDialogue,
-) -> anyhow::Result<()> {
+async fn start(bot: AutoSend<Bot>, msg: Message, dialogue: MyDialogue) -> HandlerResult {
     bot.send_message(msg.chat.id, "Let's start! What's your full name?").await?;
     dialogue.update(State::ReceiveFullName).await?;
     Ok(())
 }
 
-async fn handle_receive_full_name(
+async fn receive_full_name(
     bot: AutoSend<Bot>,
     msg: Message,
     dialogue: MyDialogue,
-) -> anyhow::Result<()> {
+) -> HandlerResult {
     match msg.text() {
         Some(text) => {
             bot.send_message(msg.chat.id, "How old are you?").await?;
@@ -87,12 +82,12 @@ async fn handle_receive_full_name(
     Ok(())
 }
 
-async fn handle_receive_age(
+async fn receive_age(
     bot: AutoSend<Bot>,
     msg: Message,
     dialogue: MyDialogue,
-    (full_name,): (String,), // Available from `State::ReceiveAge`.
-) -> anyhow::Result<()> {
+    full_name: String, // Available from `State::ReceiveAge`.
+) -> HandlerResult {
     match msg.text().map(|text| text.parse::<u8>()) {
         Some(Ok(age)) => {
             bot.send_message(msg.chat.id, "What's your location?").await?;
@@ -106,15 +101,15 @@ async fn handle_receive_age(
     Ok(())
 }
 
-async fn handle_receive_location(
+async fn receive_location(
     bot: AutoSend<Bot>,
     msg: Message,
     dialogue: MyDialogue,
     (full_name, age): (String, u8), // Available from `State::ReceiveLocation`.
-) -> anyhow::Result<()> {
+) -> HandlerResult {
     match msg.text() {
         Some(location) => {
-            let message = format!("Full name: {}\nAge: {}\nLocation: {}", full_name, age, location);
+            let message = format!("Full name: {full_name}\nAge: {age}\nLocation: {location}");
             bot.send_message(msg.chat.id, message).await?;
             dialogue.exit().await?;
         }
