@@ -1,5 +1,4 @@
-use crate::types::CallbackQuery;
-use teloxide_core::types::{ChatId, Message};
+use crate::types::{CallbackQuery, ChatId, Message, Update};
 
 /// Something that may has a chat ID.
 pub trait GetChatId {
@@ -18,3 +17,9 @@ impl GetChatId for CallbackQuery {
         self.message.as_ref().map(|mes| mes.chat.id)
     }
 }
+
+impl GetChatId for Update {
+    fn chat_id(&self) -> Option<ChatId> {
+        self.chat().map(|chat| chat.id)
+    }
+}
