@@ -2,7 +2,7 @@
 #![allow(clippy::nonstandard_macro_braces)]
 
 #[cfg(feature = "macros")]
-use teloxide::utils::command::{BotCommand, ParseError};
+use teloxide::utils::command::{BotCommands, ParseError};
 
 // We put tests here because macro expand in unit tests in module
 // teloxide::utils::command was a failure
@@ -10,7 +10,7 @@ use teloxide::utils::command::{BotCommand, ParseError};
 #[test]
 #[cfg(feature = "macros")]
 fn parse_command_with_args() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     enum DefaultCommands {
         Start(String),
@@ -26,7 +26,7 @@ fn parse_command_with_args() {
 #[test]
 #[cfg(feature = "macros")]
 fn parse_command_with_non_string_arg() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     enum DefaultCommands {
         Start(i32),
@@ -42,7 +42,7 @@ fn parse_command_with_non_string_arg() {
 #[test]
 #[cfg(feature = "macros")]
 fn attribute_prefix() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     enum DefaultCommands {
         #[command(prefix = "!")]
@@ -59,7 +59,7 @@ fn attribute_prefix() {
 #[test]
 #[cfg(feature = "macros")]
 fn many_attributes() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     enum DefaultCommands {
         #[command(prefix = "!", description = "desc")]
@@ -68,13 +68,13 @@ fn many_attributes() {
     }
 
     assert_eq!(DefaultCommands::Start, DefaultCommands::parse("!start", "").unwrap());
-    assert_eq!(DefaultCommands::descriptions(), "!start - desc\n/help\n");
+    assert_eq!(DefaultCommands::descriptions().to_string(), "!start — desc\n/help");
 }
 
 #[test]
 #[cfg(feature = "macros")]
 fn global_attributes() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(prefix = "!", rename = "lowercase", description = "Bot commands")]
     enum DefaultCommands {
         #[command(prefix = "/")]
@@ -84,13 +84,13 @@ fn global_attributes() {
 
     assert_eq!(DefaultCommands::Start, DefaultCommands::parse("/start", "MyNameBot").unwrap());
     assert_eq!(DefaultCommands::Help, DefaultCommands::parse("!help", "MyNameBot").unwrap());
-    assert_eq!(DefaultCommands::descriptions(), "Bot commands\n/start\n!help\n");
+    assert_eq!(DefaultCommands::descriptions().to_string(), "Bot commands\n\n/start\n!help");
 }
 
 #[test]
 #[cfg(feature = "macros")]
 fn parse_command_with_bot_name() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     enum DefaultCommands {
         #[command(prefix = "/")]
@@ -107,7 +107,7 @@ fn parse_command_with_bot_name() {
 #[test]
 #[cfg(feature = "macros")]
 fn parse_with_split() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     #[command(parse_with = "split")]
     enum DefaultCommands {
@@ -124,7 +124,7 @@ fn parse_with_split() {
 #[test]
 #[cfg(feature = "macros")]
 fn parse_with_split2() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     #[command(parse_with = "split", separator = "|")]
     enum DefaultCommands {
@@ -152,7 +152,7 @@ fn parse_custom_parser() {
             .map_err(|_| ParseError::Custom("First argument must be a integer!".to_owned().into()))
     }
 
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     enum DefaultCommands {
         #[command(parse_with = "custom_parse_function")]
@@ -169,7 +169,7 @@ fn parse_custom_parser() {
 #[test]
 #[cfg(feature = "macros")]
 fn parse_named_fields() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     #[command(parse_with = "split")]
     enum DefaultCommands {
@@ -186,7 +186,7 @@ fn parse_named_fields() {
 #[test]
 #[cfg(feature = "macros")]
 fn descriptions_off() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     #[command(rename = "lowercase")]
     enum DefaultCommands {
         #[command(description = "off")]
@@ -194,13 +194,13 @@ fn descriptions_off() {
         Help,
     }
 
-    assert_eq!(DefaultCommands::descriptions(), "/help\n".to_owned());
+    assert_eq!(DefaultCommands::descriptions().to_string(), "/help".to_owned());
 }
 
 #[test]
 #[cfg(feature = "macros")]
 fn rename_rules() {
-    #[derive(BotCommand, Debug, PartialEq)]
+    #[derive(BotCommands, Debug, PartialEq)]
     enum DefaultCommands {
         #[command(rename = "lowercase")]
         AaaAaa,
@@ -230,7 +230,7 @@ fn rename_rules() {
     assert_eq!(DefaultCommands::HhhHhh, DefaultCommands::parse("/HHH-HHH", "").unwrap());
 
     assert_eq!(
-        "/aaaaaa\n/BBBBBB\n/CccCcc\n/dddDdd\n/eee_eee\n/FFF_FFF\n/ggg-ggg\n/HHH-HHH\n",
-        DefaultCommands::descriptions()
+        "/aaaaaa\n/BBBBBB\n/CccCcc\n/dddDdd\n/eee_eee\n/FFF_FFF\n/ggg-ggg\n/HHH-HHH",
+        DefaultCommands::descriptions().to_string()
     );
 }
